@@ -12,7 +12,7 @@ use DBI;
 use Exception::Class::DBI;
 
 
-our $VERSION = '0.022';
+our $VERSION = '0.05';
 
 
 =head1 NAME
@@ -23,7 +23,7 @@ AxKit::App::TABOO::Data::Category - Category Data objects for TABOO
 
   use AxKit::App::TABOO::Data::Category;
   $cat = AxKit::App::TABOO::Data::Category->new();
-  $cat->load('kitten');
+  $cat->load(what => '*', limit => {catname => 'kitten'});
 
 
 =head1 DESCRIPTION
@@ -33,7 +33,7 @@ It is often convenient to lump articles together in categories. People do that t
 =cut
 
 AxKit::App::TABOO::Data::Category->elementorder("catname, name, type, uri, description");
-AxKit::App::TABOO::Data::Category->selectquery("SELECT * FROM categories WHERE catname=?");
+AxKit::App::TABOO::Data::Category->dbfrom("categories");
 
 =head1 METHODS
 
@@ -45,27 +45,6 @@ This class implements only one method, in addition to the constructor, the rest
 
 The constructor. Nothing special.
 
-=item C<all_of_type($type)>
-
-This method will return an arrayref containing the catnames of all categories of type C<$type>. This is a bit unelegant, since the typical use is to first call it on an object just created, then create an array containing Category objects based on it, but I didn't find a better solution right now... I what really needs to be done is to add plural versions of each data class, but there are details that I need to figure out. See comment in the parent class POD. 
-
-
-
-=cut
-
-sub all_of_type {
-  my $self = shift;
-  my $type = shift;
-  my $dbh = DBI->connect($self->dbstring(), 
-			 $self->dbuser(), 
-			 $self->dbpasswd(),  
-			 { PrintError => 0,
-			   RaiseError => 0,
-			   HandleError => Exception::Class::DBI->handler
-			 });
-  return $dbh->selectcol_arrayref("SELECT catname FROM categories WHERE type=?", {}, $type);
-}
-
 
 =item C<load_name($catname)>
 
@@ -148,7 +127,7 @@ The C<write_xml()> method, implemented in the parent class, can be used to creat
 
 =back
 
-However, the root element may change depending on what kind of category we have. The default is C<primcat>.
+However, the root element may change depending on what kind of category we have. The default is C<category>.
 
 =cut
 
@@ -161,7 +140,7 @@ sub new {
 		type => undef,
 		uri => undef,
 		description => undef,
-		XMLELEMENT => 'primcat',	
+		XMLELEMENT => 'category',	
 		XMLNS => 'http://www.kjetil.kjernsmo.net/software/TABOO/NS/Category/Output',
 		ONFILE => undef,
     };
@@ -177,5 +156,7 @@ sub new {
 See L<AxKit::App::TABOO>.
 
 =cut
-    
+
 1;
+
+
