@@ -6,6 +6,7 @@ use Apache::AxKit::Language::XSP::SimpleTaglib;
 use Apache::AxKit::Exception;
 use AxKit;
 use AxKit::App::TABOO::Data::Category;
+use AxKit::App::TABOO::Data::Plurals::Categories;
 use Apache::AxKit::Plugin::BasicSession;
 use Time::Piece ':override';
 use Data::Dumper;
@@ -15,14 +16,13 @@ use XML::LibXML;
 use vars qw/$NS/;
 
 
-our $VERSION = '0.021';
+our $VERSION = '0.05';
 
 
 =head1 NAME
 
 AxKit::App::TABOO::XSP::Category - Category management tag library for TABOO
 
-
 =head1 SYNOPSIS
 
 Add the category: namespace to your XSP C<<xsp:page>> tag, e.g.:
@@ -61,8 +61,9 @@ package AxKit::App::TABOO::XSP::Category::Handlers;
 
 This tag will replace itself with some structured XML containing all
 categories of type C<foo>.  It relates to the TABOO Data object
-L<AxKit::App::TABOO::Data::Category>, and calls on that to do the hard
-work. See the documentation of that class to see the available types.
+L<AxKit::App::TABOO::Data::Plurals::Category>, and calls on that to do
+the hard work. See the documentation of that class to see the
+available types.
 
 The root element of the returned object is C<categories> and each category is wrapped in an element (surprise!) C<category> and contains C<catname> and C<name>. 
 
@@ -70,18 +71,14 @@ The root element of the returned object is C<categories> and each category is wr
 
 sub get_categories : struct attribOrChild(type) {
     return << 'EOC'
-    my $tmp = AxKit::App::TABOO::Data::Category->new();
-    my $cats = $tmp->all_of_type($attr_type);
+    my $cats = AxKit::App::TABOO::Data::Plurals::Categories->new();
+    $cats->load(what => '*', limit => {type => $attr_type});
     my $doc = XML::LibXML::Document->new();
     my $root = $doc->createElementNS('http://www.kjetil.kjernsmo.net/software/TABOO/NS/Category/Output', 'categories');
     $root->setAttribute('type', $attr_type);
     $doc->setDocumentElement($root);
-    foreach my $catname (@{$cats}) {
-	my $cat = AxKit::App::TABOO::Data::Category->new();
-	$cat->load_name($catname); # We don't care about the output
-	$cat->xmlelement('category');
-	$doc = $cat->write_xml($doc, $root);
-    }
+    $cats->xmlelement('primcat');
+    $doc = $cats->write_xml($doc, $root);
     $doc;
 EOC
 }
@@ -115,7 +112,7 @@ EOC
 #      if (! $args{'lasttimestamp'}) {
 #  	$args{'lasttimestamp'} = $timestamp->datetime;
 #      }
-#      $story->apache_request_data(\%args);
+#      $story->populate(\%args);
 #      $story->save();    
 #  EOC
 #  }
